Project hosting
===============

`Storyboard`_ hosts the Sahara project. The Sahara project group homepage on
Storyboard is https://storyboard.openstack.org/#!/project_group/74.

Launchpad credentials
---------------------

Creating a login on Launchpad is important even if you don't use the Launchpad
site itself, since Launchpad credentials are used for logging in on several
OpenStack-related sites. These sites include:

* `Wiki`_
* Gerrit (see :doc:`gerrit`)
* Jenkins (see :doc:`jenkins`)

Mailing list
------------

The mailing list email is ``openstack-discuss@lists.openstack.org``; use the
subject prefix ``[sahara]`` to address the team. To participate in the
mailing list subscribe to the list at
http://lists.openstack.org/cgi-bin/mailman/listinfo

Bug tracking
------------

Report Sahara bugs/stories at the various project under the Sahara project
group https://storyboard.openstack.org/#!/project_group/74

Feature requests (Specs)
-----------------------------

Sahara uses specs to track feature requests. They provide a high-level summary
of proposed changes and track associated commits. Sahara also uses specs for
in-depth descriptions and discussions of blueprints. Specs follow a defined
format and are submitted as change requests to the openstack/sahara-specs
repository.

Technical support
-----------------

Sahara uses `Ask OpenStack`_ to track Sahara technical support questions.
Questions related to Sahara should be tagged with 'sahara'.

.. _Storyboard: https://storyboard.openstack.org
.. _Wiki: http://wiki.openstack.org/sahara
.. _Ask OpenStack: https://ask.openstack.org
